<?php

namespace Rhymix\Framework\Drivers\SMS;

/**
 * The CoolSMS SMS driver.
 */
class SmsBao extends Base implements \Rhymix\Framework\Drivers\SMSInterface
{
    /**
     * API specifications.
     */
    protected static $_spec = array(
        'max_recipients' => 1000,
        'sms_max_length' => 90,
        'sms_max_length_in_charset' => 'CP949',
        'lms_supported' => true,
        'lms_supported_country_codes' => array(82),
        'lms_max_length' => 2000,
        'lms_max_length_in_charset' => 'CP949',
        'lms_subject_supported' => true,
        'lms_subject_max_length' => 40,
        'mms_supported' => true,
        'mms_supported_country_codes' => array(82),
        'mms_max_length' => 2000,
        'mms_max_length_in_charset' => 'CP949',
        'mms_subject_supported' => true,
        'mms_subject_max_length' => 40,
        'image_allowed_types' => array('jpg', 'gif', 'png'),
        'image_max_dimensions' => array(2048, 2048),
        'image_max_filesize' => 300000,
        'delay_supported' => true,
    );

    /**
     * Config keys used by this driver are stored here.
     */
    protected static $_required_config = array('api_key', 'api_secret');

    /**
     * Check if the current SMS driver is supported on this server.
     *
     * This method returns true on success and false on failure.
     *
     * @return bool
     */
    public static function isSupported()
    {
        return true;
    }

    /**
     * Send a message.
     *
     * This method returns true on success and false on failure.
     *
     * @param array $messages
     * @param object $original
     * @return bool
     */
    public function send(array $messages, \Rhymix\Framework\SMS $original)
    {

        try
        {
            $sender = new \Nurigo\Api\Message($this->_config['api_key'], $this->_config['api_secret']);
            $status = true;

            foreach ($messages as $i => $message)
            {
                $statusStr = array(
                    "0" => "短信发送成功",
                    "-1" => "参数不全",
                    "-2" => "服务器空间不支持,请确认支持curl或者fsocket，联系您的空间商解决或者更换空间！",
                    "30" => "密码错误",
                    "40" => "账号不存在",
                    "41" => "余额不足",
                    "42" => "帐户已过期",
                    "43" => "IP地址限制",
                    "50" => "内容含有敏感词"
                );
                $smsapi = "http://api.smsbao.com/";
                $user = $this->_config['api_key']; //短信平台帐号
                $pass = md5($this->_config['api_secret']); //短信平台密码
                $content=$message->content;//要发送的短信内容
                $phone = implode(',', $message->to);//要发送短信的手机号码
                $sendurl = $smsapi."sms?u=".$user."&p=".$pass."&m=".$phone."&c=".urlencode($content);
                $result =file_get_contents($sendurl) ;
                if ($result !=0)
                {
                    $error_codes = implode(', ', $statusStr[$result] ?: array('Unknown'));
                    $original->addError('Error (' . $error_codes . ') while sending message ' . ($i + 1) . ' of ' . count($messages) . ' to ' . $phone);
                    $status = false;
                }
            }

            return $status;
        }
        catch (\Nurigo\Exceptions\CoolsmsException $e)
        {
            $message->errors[] = class_basename($e) . ': ' . $e->getMessage();
            return false;
        }
    }
}
